==> Scraper-1.37.tar.gz: Scraper-1.37/lib/WWW/Search/Scraper/apartments.pm <==

package WWW::Search::Scraper::apartments;

=pod

=head1 NAME

WWW::Search::Scraper::apartments - class for searching www.apartments.com


=head1 SYNOPSIS

    require WWW::Search::Scraper;
    $search = new WWW::Search::Scraper('apartments');


=head1 DESCRIPTION

This class is an apartments specialization of WWW::Search.
It handles making and interpreting apartments searches
F<http://www.apartments.com>.


=head1 OPTIONS

To do.

=head1 OPTIONS

To do

=head1 AUTHOR

C<WWW::Search::apartments> is written and maintained
by Glenn Wood, <glenwood@alumni.caltech.edu>.

The best place to obtain C<WWW::Search::apartments>
is from Glenn's releases on CPAN. Because www.apartments.com
sometimes changes its format in between his releases, 
sometimes more up-to-date versions can be found at
F<http://alumni.caltech.edu/~glenwood/SOFTWARE/index.html>.

=head1 COPYRIGHT

Copyright (c) 2001 Glenn Wood
All rights reserved.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut


#####################################################################

use strict;
use vars qw($VERSION @ISA);
@ISA = qw(WWW::Search::Scraper);
$VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
use WWW::Search::Scraper::Response;

use WWW::Search::Scraper(qw(1.34));
require WWW::SearchResult;

use strict;

# SAMPLE
# http://www.apartments.com/search/oasis.dll?mfcisapicommand=quicksearch&QSearchType=1&city=New%20York&state=NY&numbeds=0&minrnt=0&maxrnt=9999
#
sub native_setup_search
{
    my $self = shift;
    
    $self->{'_options'}{'scraperQuery'} =
    [ 'QUERY'       # Type of query generation is 'QUERY'
      # This is the basic URL on which to build the query.
     ,'http://www.apartments.com/search/oasis.dll?mfcisapicommand=quicksearch&QSearchType=1&'
      # This is the Scraper attributes => native input fields mapping
     ,{'scraperQuery' => 'city'
      }
      # Some more options for the Scraper operation.
     ,{'cookies' => 0
      }
    ];

    # Set the default field values.
    $self->{'_options'}{'numbeds'} = 0;
    $self->{'_options'}{'minrnt'}  = 0;
    $self->{'_options'}{'maxrnt'}  = 9999;

    # scraperFrame describes the format of the result page.
    $self->{'_options'}{'scrapeFrame'} = 
[ 'HTML', 
  [ 
      [ 'COUNT', '<strong>Matches: (\d+)</strong>' ]
     ,[ 'NEXT', 2, \&getNextPage ]
     ,[ 'BODY', '<form action="oasis.dll" method="GET" name="Form1">', undef,      # There are two forms in this
         [ [ 'BODY', '<form action="oasis.dll" method="GET" name="Form1">', undef, #  result, by the same name!
              [  
                [ 'TABLE', '#0',
                   [
                      [ 'TR' ] # "Visual Listings".
                     ,[ 'HIT*' ,
                        [ [ 'TR', 
                             [
                                [ 'TD' ,
                                    [  [ 'TABLE',  # the first sub-table is the visual image, et.al.
                                         [ 
                                             [ 'TR' ] # hmmm . . .
                                            ,[ 'TR' ] # hmmm . . .
                                            ,[ 'TR' ] # anchor to visual tour
                                       ] ]
                                    ]
                                ]
                               ,[ 'TD',
                                   [
                                      [ 'TABLE',
                                        [
                                          [ 'TR',
                                            [
                                               [ 'TD', [ [ 'A', 'url', 'title' ] ] ]
                                              ,[ 'TD', 'price' ]
                                              ,[ 'RESIDUE', 'location' ]
                                            ]
                                         ,[ 'TR' ] # ???
                                         ,[ 'TR',
                                           ,[ 'TD', 'description' ]
                                          ]
                                         ,[ 'TR' ] # this row contains anchors to images illustrating the apartment's features.
                                        ]
                                     ]
                                   ]
                                 ]
                               ]
                            ]
                          ]
                         ,[ 'TR' ] # this row contains a horizontal rule separating each result.
                        ]
                      ]
                   ]
                ] 
              ]
           ]
        ] 
    ] 
  ]
];

    # WWW::Search::Scraper understands all that and will setup the search.
    return $self->SUPER::native_setup_search(@_);
}



# www.apartment.com sets its NEXT button in a submit, with various labels.
# e.g.
# <input type="button" 
#       onclick="javascript:document.location=
#                '/search/oasis.dll?page=Results&resultpos=11&QSearchType=1&minrent=0&maxrent=9999&allsizes=1&allbaths=1&month=0&status=4&state=NY&city=NEW+YORK&prvpg=7'" 
#       value="Last 7 &gt;&gt;">
sub getNextPage {
    my ($self, $hit, $dat) = @_;
    return undef unless
        $dat =~ m-value="Modify Search Criteria".*onclick="javascript:document\.location='(/search/oasis\.dll\?page=Results[^']*?)'[^>]*?&gt;&gt;">-s;
    my $nxt = $1;
    my $url = URI::URL->new($1, $self->{'_base_url'});
    $url = $url->abs;
    return $url;
}


use WWW::Search::Scraper::Response;
sub newHit {
    my $self = new WWW::Search::Scraper::Response;
    return $self;
}

1;

==> Scraper-2.00.tar.gz: Scraper-2.00/lib/WWW/Search/Scraper/apartments.pm <==

package WWW::Search::Scraper::apartments;

=pod

=head1 NAME

WWW::Search::Scraper::apartments - class for searching www.apartments.com


=head1 SYNOPSIS

    require WWW::Search::Scraper;
    $search = new WWW::Search::Scraper('apartments');


=head1 DESCRIPTION

This class is an apartments specialization of WWW::Search.
It handles making and interpreting apartments searches
F<http://www.apartments.com>.


=head1 OPTIONS

To do.

=head1 OPTIONS

To do

=head1 AUTHOR

C<WWW::Search::apartments> is written and maintained
by Glenn Wood, <glenwood@alumni.caltech.edu>.

The best place to obtain C<WWW::Search::apartments>
is from Glenn's releases on CPAN. Because www.apartments.com
sometimes changes its format in between his releases, 
sometimes more up-to-date versions can be found at
F<http://alumni.caltech.edu/~glenwood/SOFTWARE/index.html>.

=head1 COPYRIGHT

Copyright (c) 2001 Glenn Wood
All rights reserved.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut


#####################################################################

use strict;
use vars qw($VERSION @ISA);
@ISA = qw(WWW::Search::Scraper);
$VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
use WWW::Search::Scraper::Response;

use WWW::Search::Scraper(qw(1.34));

use strict;

# SAMPLE
# http://www.apartments.com/search/oasis.dll?mfcisapicommand=quicksearch&QSearchType=1&city=New%20York&state=NY&numbeds=0&minrnt=0&maxrnt=9999
#
sub native_setup_search
{
    my $self = shift;
    
    $self->{'_options'}{'scraperQuery'} =
    [ 'QUERY'       # Type of query generation is 'QUERY'
      # This is the basic URL on which to build the query.
     ,'http://www.apartments.com/search/oasis.dll?mfcisapicommand=quicksearch&QSearchType=1&'
      # This is the Scraper attributes => native input fields mapping
     ,{'nativeQuery' => 'city'
         ,'nativeDefaults' =>
                         {    'numbeds' => 0
                             ,'minrnt'  => 0
                             ,'maxrtt'  => '9999'
                         }
      }
      # Some more options for the Scraper operation.
     ,{'cookies' => 0
      }
    ];

    # scraperFrame describes the format of the result page.
    $self->{'_options'}{'scrapeFrame'} = 
[ 'HTML', 
  [ 
      [ 'COUNT', '<strong>Matches: (\d+)</strong>' ]
     ,[ 'NEXT', 2, \&getNextPage ]
     ,[ 'BODY', '<form action="oasis.dll" method="GET" name="Form1">', undef,      # There are two forms in this
         [ [ 'BODY', '<form action="oasis.dll" method="GET" name="Form1">', undef, #  result, by the same name!
              [  
                [ 'TABLE', '#0',
                   [
                      [ 'TR' ] # "Visual Listings".
                     ,[ 'HIT*' ,
                        [ [ 'TR', 
                             [
                                [ 'TD' ,
                                    [  [ 'TABLE',  # the first sub-table is the visual image, et.al.
                                         [ 
                                             [ 'TR' ] # hmmm . . .
                                            ,[ 'TR' ] # hmmm . . .
                                            ,[ 'TR' ] # anchor to visual tour
                                       ] ]
                                    ]
                                ]
                               ,[ 'TD',
                                   [
                                      [ 'TABLE',
                                        [
                                          [ 'TR',
                                            [
                                               [ 'TD', [ [ 'A', 'url', 'title' ] ] ]
                                              ,[ 'TD', 'price' ]
                                              ,[ 'RESIDUE', 'location' ]
                                            ]
                                         ,[ 'TR' ] # ???
                                         ,[ 'TR',
                                           ,[ 'TD', 'description' ]
                                          ]
                                         ,[ 'TR' ] # this row contains anchors to images illustrating the apartment's features.
                                        ]
                                     ]
                                   ]
                                 ]
                               ]
                            ]
                          ]
                         ,[ 'TR' ] # this row contains a horizontal rule separating each result.
                        ]
                      ]
                   ]
                ] 
              ]
           ]
        ] 
    ] 
  ]
];

    # WWW::Search::Scraper understands all that and will setup the search.
    return $self->SUPER::native_setup_search(@_);
}



# www.apartment.com sets its NEXT button in a submit, with various labels.
# e.g.
# <input type="button" 
#       onclick="javascript:document.location=
#                '/search/oasis.dll?page=Results&resultpos=11&QSearchType=1&minrent=0&maxrent=9999&allsizes=1&allbaths=1&month=0&status=4&state=NY&city=NEW+YORK&prvpg=7'" 
#       value="Last 7 &gt;&gt;">
sub getNextPage {
    my ($self, $hit, $dat) = @_;
    return undef unless
        $dat =~ m-value="Modify Search Criteria".*onclick="javascript:document\.location='(/search/oasis\.dll\?page=Results[^']*?)'[^>]*?&gt;&gt;">-s;
    my $nxt = $1;
    my $url = URI::URL->new($1, $self->{'_base_url'});
    $url = $url->abs;
    return $url;
}

1;
